﻿Public Class frmMain

    ' Here we declare a myK8055 object: it is an instance of the K8055 class. All the communications with
    ' the Velleman K8055 are done trough this object.
    Private WithEvents myK8055 As New K8055()



    ' FrmMain_Load is the main sub for the program. It is called when the form is first loaded. Here we
    ' can add some initialisation code.
    Private Sub frmMain_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        ' The form contains two progress bars, to indicate the state of the analog input channels.
        ' Their min/max boundaries needs to be set before you can use them properly. This is done
        ' here:
        prgAD1.Minimum = 0
        prgAD1.Maximum = 255
        prgAD2.Minimum = 0
        prgAD2.Maximum = 255

        ' The form contains 1 trackbar control. We will set its boundaries here:
        trackOut1.Minimum = 0
        trackOut1.Maximum = 255

        ' The form contains two checkboxes to indicate the state of the digital inputs 1 & 2. 
        ' They are for indication only, so the user should not be allowed to change the checkbox's value.
        ' We will disable them:
        chkInput1.Enabled = False
        chkInput2.Enabled = False

        ' All the controls that are used to manipulate the card are placed inside a frame: the ControlFrame.
        ' I used its Enabled property to enable/disable all controls at the same time. This prevents you can
        ' send commands to the card when it is not connected.
        ControlFrame.Enabled = False
    End Sub





    ' cmdConnect_Click is an event that is raised when someones clicks the CONNECT button. Here we will
    ' create a connection with the K8055. The K8055 is disconnected again if we press the button a second time.
    '
    Private Sub cmdConnect_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdConnect.Click

        ' The declaration of the variables that are needed for this event.
        Dim success As Boolean                  ' success is a boolean that will indicate if the K8055 could be connected to
        Dim SK5 As Boolean = chkSK5.Checked     ' SK5 contains the state of the SK5 checkbox. 
        Dim SK6 As Boolean = chkSK6.Checked     ' SK5 contains the state of the SK5 checkbox. 

        ' First we need to check if the K8055 is already connected. 
        If myK8055.isConnected = True Then
            ' The K8055 is connected. So we will disconnect the card now ...
            myK8055.disconnect()

            ' Stop the timer_reader
            timerReader.Enabled = False

            ' Update the label for the button
            cmdConnect.Text = "Connect"

            ' Disable the controls in the controlFrame
            ControlFrame.Enabled = False


        Else
            ' Now we try to connect to the K8055 through the myK8055 object. The result is stored in 
            ' the success variable. It can be either True of False.
            success = myK8055.connect(SK5, SK6)

            ' Now we will check if a connection could be established.
            If success = True Then
                ' The connection attempt succeeded: show a message
                MsgBox("Connection Established!", _
                        MsgBoxStyle.OkOnly + MsgBoxStyle.Information, _
                        "Connection Established")

                ' Set the timer_reader
                ' Timer_Reader is a timer I placed on the form. When enabled the event 
                ' timerReader_Tick is called every second.
                timerReader.Enabled = True
                timerReader.Interval = 1000

                ' Update the label for the button
                cmdConnect.Text = "Disconnect"

                ' Enable the controls in the controlFrame
                ControlFrame.Enabled = True

            Else
                ' The connection attempt failed: we will show an error message
                MsgBox("Connection Failed!", _
                        MsgBoxStyle.OkOnly + MsgBoxStyle.Critical, _
                        "Connection Failed")

                ' Stop the timer_reader
                timerReader.Enabled = False

                ' Update the label for the button
                cmdConnect.Text = "Connect"

                ' Enable the controls in the controlFrame
                ControlFrame.Enabled = False
            End If
        End If
    End Sub





    ' cmdToggle1_Click is an event which is triggered when someone clicks the cmdToggle button. 
    ' Clicking it will invert the state of digital output 1.
    Private Sub cmdToggle1_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdToggle1.Click
        ' Declaration of the variables
        Dim currentState As Boolean     ' A boolean to indicate the current state of the output. It can be true or false.

        ' We will now read the current state of the digital output 1
        currentState = myK8055.getDigitalOutput(1)

        ' We will now invert the channel.
        If currentState = True Then
            ' The channel is now on, so we turn it off ...
            myK8055.clearDigitalOutput(1)
        Else
            ' The channel is now off, so we turn it on ...
            myK8055.setDigitalOutput(1)
        End If
    End Sub





    ' cmdSetAll_Click is an event which is triggered when someone clicks the cmdSetAll button.
    ' Clicking it will set all digital outputs
    Private Sub cmdSetAll_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdSetAll.Click
        ' Send the command to set all outputs
        myK8055.setAllDigitalOutputs()
    End Sub





    ' cmdClearAll_Click is an event which is triggered when someone clicks the cmdClearAll button.
    ' Clicking it will clear all digital outputs
    Private Sub cmdClearAll_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdClearAll.Click
        ' Send the command to clear all outputs
        myK8055.clearAllDigtalOutputs()
    End Sub






    ' timerReader_Tick is an event that belongs to the timerReader control, which is placed on the form. This control
    ' provides a way to let things happen at a fixed time interval. 
    ' In this application the timerReader is used to read the inputs of the K8055 card, it is launched every second.
    Private Sub timerReader_Tick(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles timerReader.Tick
        ' First we read the values of the analog input channels. They can have a value between 0 and 255 (the A/D
        ' convertor is eight-bit, so there are 2^8=256 possible values).
        prgAD1.Value = myK8055.ReadAnalogInput(1)
        prgAD2.Value = myK8055.ReadAnalogInput(2)


        ' Then we read the values of digital inputs 1 and 2. The two checkboxes on the form will indicate their actual
        ' state. In this example I defined two helper variables. The read values are first put in here, then they are
        ' assigned to the chkInput1 & 2 checkboxes.
        Dim digitalInput1 As Boolean
        Dim digitalInput2 As Boolean

        digitalInput1 = myK8055.getDigitalInput(1)
        digitalInput2 = myK8055.getDigitalInput(2)

        chkInput1.Checked = digitalInput1
        chkInput2.Checked = digitalInput2
    End Sub





    ' trackOut1_Scroll is the event that is launched when the user changes the value of the slider. We will use it to

    Private Sub trackOut1_Scroll(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles trackOut1.Scroll
        ' First we need to get the value of the trackOut1 control. This is a value between 0 and 255 (we can be sure
        ' of this because we set the boundaries during the loading of the form (see the frmMain_Load).
        Dim value As Integer
        value = trackOut1.Value

        ' We will send the retrieved value to the K8000.
        myK8055.setAnalogOutputToValue(1, value)    ' 1 specifies we want to control analog output 1. (you can enter 1 or 2).
    End Sub
End Class
